tdl.event.MouseMotion

Package tdl :: Module event :: Class MouseMotion |
[frames] | no frames]

# Class MouseMotion

source code

    object --+
             |
         Event --+
                 |
                MouseMotion

Fired when the mouse is moved.

Instance Methods
__init__(self, pos, cell, motion, cellmotion) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__repr__(self) List an events public attributes when printed. (Inherited from tdl.event.Event) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| type = ``'``MOUSEMOTION``'`` String constant representing the type of event.

Instance Variables
| pos (x, y) position of the mouse on the screen.
| cell (x, y) position of the mouse snapped to a cell on the root console.
| motion (x, y) motion of the mouse on the screen.
| cellmotion (x, y) mostion of the mouse moving over cells on the root console.

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, pos, cell, motion, cellmotion) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

Instance Variable Details

### pos (x, y) position of the mouse on the screen. type: (int, int)

### cell (x, y) position of the mouse snapped to a cell on the root console. type: (int, int)

### motion (x, y) motion of the mouse on the screen. type: (int, int)

### cellmotion (x, y) mostion of the mouse moving over cells on the root console. type: (int, int)